@@ -12,6 +12,10 @@ from pymavlink import mavutil
 if platform.system() == 'Darwin':
     import gnureadline as readline
 elif platform.system() == 'Windows' and sys.version_info >= (3, 0):
+    # Python 3.8 defaults to Proactor event loop, which doesn't work well
+    if sys.version_info >= (3, 8):
+        import asyncio
+        asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
     from prompt_toolkit import prompt, PromptSession
     from prompt_toolkit.completion import Completer, Completion
     from prompt_toolkit.shortcuts import CompleteStyle
@@ -184,11 +188,12 @@ def complete_variable(text):
     else:
         suffix = ''
 
-    m1 = re.match("^(.*?)([A-Z0-9][A-Z0-9_]*)[.]([A-Za-z0-9_]*)$", text)
+    m1 = re.match("^(.*?)([A-Z0-9][A-Z0-9_]*(\[[0-9]\])?)[.]([A-Za-z0-9_]*)$", text)
     if m1 is not None:
         prefix = m1.group(1)
         mtype = m1.group(2)
-        fname = m1.group(3)
+        instance = m1.group(3)
+        fname = m1.group(4)
         if mtype in rline_mpstate.status.msgs:
             ret = []
             for f in rline_mpstate.status.msgs[mtype].get_fieldnames():
@@ -196,7 +201,7 @@ def complete_variable(text):
                     ret.append(prefix + mtype + '.' + f + suffix)
             return ret
         return []
-    m2 = re.match("^(.*?)([A-Z0-9][A-Z0-9_]*)$", text)
+    m2 = re.match("^(.*?)([A-Z0-9][A-Z0-9_]*(\[[0-9]\])?)$", text)
     prefix = m2.group(1)
     mtype = m2.group(2)
     ret = []
