@@ -23,7 +23,7 @@ class BatteryModule(mp_module.MPModule):
         self.high_servo_voltage = -1
         self.last_servo_warn_time = 0
         self.last_vcc_warn_time = 0
-        
+
         self.settings.append(
             MPSetting('battwarn', int, 1, 'Battery Warning Time', tab='Battery'))
         self.settings.append(
@@ -32,7 +32,7 @@ class BatteryModule(mp_module.MPModule):
             MPSetting('servowarn', float, 4.3, 'Servo voltage warning level'))
         self.settings.append(
             MPSetting('vccwarn', float, 4.3, 'Vcc voltage warning level'))
-        self.settings.append(MPSetting('numcells', int, 0, range=(0,10), increment=1))
+        self.settings.append(MPSetting('numcells', int, 0, range=(0,50), increment=1))
         self.battery_period = mavutil.periodic_event(5)
 
     def cmd_bat(self, args):
@@ -46,7 +46,7 @@ class BatteryModule(mp_module.MPModule):
     def battery_report(self):
         batt_mon = int(self.get_mav_param('BATT_MONITOR',0))
 
-        #report voltage level only 
+        #report voltage level only
         battery_string = ''
         if batt_mon == 3:
             battery_string = 'Batt: %.2fV' % (float(self.voltage_level) / 1000.0)
@@ -71,7 +71,7 @@ class BatteryModule(mp_module.MPModule):
         if self.settings.numcells != 0 and self.per_cell < self.settings.batwarncell and time.time() > self.last_battery_cell_announce_time + 60*self.settings.battwarn:
             self.say("Cell warning")
             self.last_battery_cell_announce_time = time.time()
-            
+
 
     def vcell_to_battery_percent(self, vcell):
         '''convert a cell voltage to an approximate
@@ -112,11 +112,11 @@ class BatteryModule(mp_module.MPModule):
                     # prevent continuous announcements on power down
                     self.high_servo_voltage = Vservo
 
-        if Vcc < self.settings.vccwarn:
+        if Vcc > 0 and Vcc < self.settings.vccwarn:
             if now - self.last_vcc_warn_time > 30:
                 self.last_vcc_warn_time = now
                 self.say("Vcc %.1f" % Vcc)
-        
+
 
     def mavlink_packet(self, m):
         '''handle a mavlink packet'''
