@@ -37,6 +37,17 @@ flightmodes = None
 # Global var to hold the GUI menu element
 TopMenu = None
 
+def xml_unescape(e):
+    '''unescape < amd >'''
+    e = e.replace('&gt;', '>')
+    e = e.replace('&lt;', '<')
+    return e
+
+def xml_escape(e):
+    '''escape < amd >'''
+    e = e.replace('>', '&gt;')
+    e = e.replace('<', '&lt;')
+    return e
 
 class MEStatus(object):
     '''status object to conform with mavproxy structure for modules'''
@@ -207,6 +218,10 @@ def expression_ok(expression, msgs=None):
         msgs = mestate.status.msgs
     for f in fields:
         try:
+            if f.endswith(">"):
+                a2 = f.rfind("<")
+                if a2 != -1:
+                    f = f[:a2]
             if f.endswith(':2'):
                 f = f[:-2]
             if f[-1] == '}':
@@ -234,15 +249,19 @@ def load_graph_xml(xml, filename, load_all=False):
         return []
     if not hasattr(root, 'graph'):
         return []
+    names = set()
     for g in root.graph:
         name = g.attrib['name']
         expressions = [e.text for e in g.expression]
         if load_all:
-            ret.append(GraphDefinition(name, e, g.description.text, expressions, filename))
+            if not name in names:
+                ret.append(GraphDefinition(name, expressions[0], g.description.text, expressions, filename))
+            names.add(name)
             continue
         if have_graph(name):
             continue
         for e in expressions:
+            e = xml_unescape(e)
             if expression_ok(e):
                 ret.append(GraphDefinition(name, e, g.description.text, expressions, filename))
                 break
@@ -252,16 +271,10 @@ def load_graphs():
     '''load graphs from mavgraphs.xml'''
     mestate.graphs = []
     gfiles = ['mavgraphs.xml']
-    if 'HOME' in os.environ:
-        for dirname, dirnames, filenames in os.walk(os.path.join(os.environ['HOME'], ".mavproxy")):
-            for filename in filenames:
-                if filename.lower().endswith('.xml'):
-                    gfiles.append(os.path.join(dirname, filename))
-    elif 'LOCALAPPDATA' in os.environ:
-        for dirname, dirnames, filenames in os.walk(os.path.join(os.environ['LOCALAPPDATA'], "MAVProxy")):
-            for filename in filenames:
-                if filename.lower().endswith('.xml'):
-                    gfiles.append(os.path.join(dirname, filename))
+    for dirname, dirnames, filenames in os.walk(mp_util.dot_mavproxy()):
+        for filename in filenames:
+            if filename.lower().endswith('.xml'):
+                gfiles.append(os.path.join(dirname, filename))
 
     for file in gfiles:
         if not os.path.exists(file):
@@ -397,27 +410,14 @@ def cmd_fft(args):
 def save_graph(graphdef):
     '''save a graph as XML'''
     if graphdef.filename is None:
-        if 'HOME' in os.environ:
-            dname = os.path.join(os.environ['HOME'], '.mavproxy')
-            if os.path.exists(dname):
-                mp_util.mkdir_p(dname)
-                graphdef.filename = os.path.join(dname, 'mavgraphs.xml')
-        elif 'LOCALAPPDATA' in os.environ:
-            dname = os.path.join(os.environ['LOCALAPPDATA'], 'MAVProxy')
-            if os.path.exists(dname):
-                mp_util.mkdir_p(dname)
-                graphdef.filename = os.path.join(dname, 'mavgraphs.xml')
-        else:
-            graphdef.filename = 'mavgraphs.xml'
-    if graphdef.filename is None:
-        print("No file to save graph to")
-        return
+        graphdef.filename = os.path.join(mp_util.dot_mavproxy(), 'mavgraphs.xml')
     contents = None
     try:
         contents = open(graphdef.filename).read()
         graphs = load_graph_xml(contents, graphdef.filename, load_all=True)
     except Exception as ex:
         graphs = []
+        print(ex)
     if contents is not None and len(graphs) == 0:
         print("Unable to parse %s" % graphdef.filename)
         return
@@ -443,6 +443,7 @@ def save_graph(graphdef):
             g.description = ''
         f.write("  <description>%s</description>\n" % g.description.strip())
         for e in g.expressions:
+            e = xml_escape(e)
             f.write("  <expression>%s</expression>\n" % e.strip())
         f.write(" </graph>\n\n")
     f.write("</graphs>\n")
@@ -589,6 +590,7 @@ subsystems = {
     26 : "FAILSAFE_SENSORS",
     27 : "FAILSAFE_LEAK",
     28 : "PILOT_INPUT",
+    29 : "FAILSAFE_VIBE",
 }
 
 error_codes = { # not used yet
@@ -874,7 +876,7 @@ if __name__ == "__main__":
         try:
             version = pkg_resources.require("mavproxy")[0].version
         except Exception as e:
-            start_script = os.path.join(os.environ['LOCALAPPDATA'], ".mavproxy", "version.txt")
+            start_script = mp_util.dot_mavproxy("version.txt")
             f = open(start_script, 'r')
             version = f.readline()
         print("MAVExplorer Version: " + version)
